@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     AutoTuneDesiredStateType,
@@ -21,6 +21,7 @@ from .literals import (
     DeploymentStatusType,
     DescribePackagesFilterNameType,
     DomainPackageStatusType,
+    EngineTypeType,
     InboundConnectionStatusCodeType,
     LogTypeType,
     OpenSearchPartitionInstanceTypeType,
@@ -142,6 +143,7 @@ __all__ = (
     "InstanceLimitsTypeDef",
     "InstanceTypeDetailsTypeDef",
     "LimitsTypeDef",
+    "ListDomainNamesRequestRequestTypeDef",
     "ListDomainNamesResponseTypeDef",
     "ListDomainsForPackageRequestRequestTypeDef",
     "ListDomainsForPackageResponseTypeDef",
@@ -249,7 +251,7 @@ AddTagsRequestRequestTypeDef = TypedDict(
     "AddTagsRequestRequestTypeDef",
     {
         "ARN": str,
-        "TagList": List["TagTypeDef"],
+        "TagList": Sequence["TagTypeDef"],
     },
 )
 
@@ -337,7 +339,7 @@ AutoTuneOptionsInputTypeDef = TypedDict(
     "AutoTuneOptionsInputTypeDef",
     {
         "DesiredState": AutoTuneDesiredStateType,
-        "MaintenanceSchedules": List["AutoTuneMaintenanceScheduleTypeDef"],
+        "MaintenanceSchedules": Sequence["AutoTuneMaintenanceScheduleTypeDef"],
     },
     total=False,
 )
@@ -496,11 +498,11 @@ _OptionalCreateDomainRequestRequestTypeDef = TypedDict(
         "CognitoOptions": "CognitoOptionsTypeDef",
         "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
-        "AdvancedOptions": Dict[str, str],
-        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
+        "AdvancedOptions": Mapping[str, str],
+        "LogPublishingOptions": Mapping[LogTypeType, "LogPublishingOptionTypeDef"],
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsInputTypeDef",
-        "TagList": List["TagTypeDef"],
+        "TagList": Sequence["TagTypeDef"],
         "AutoTuneOptions": "AutoTuneOptionsInputTypeDef",
     },
     total=False,
@@ -698,7 +700,7 @@ DescribeDomainResponseTypeDef = TypedDict(
 DescribeDomainsRequestRequestTypeDef = TypedDict(
     "DescribeDomainsRequestRequestTypeDef",
     {
-        "DomainNames": List[str],
+        "DomainNames": Sequence[str],
     },
 )
 
@@ -713,7 +715,7 @@ DescribeDomainsResponseTypeDef = TypedDict(
 DescribeInboundConnectionsRequestRequestTypeDef = TypedDict(
     "DescribeInboundConnectionsRequestRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -763,7 +765,7 @@ DescribeInstanceTypeLimitsResponseTypeDef = TypedDict(
 DescribeOutboundConnectionsRequestRequestTypeDef = TypedDict(
     "DescribeOutboundConnectionsRequestRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -783,7 +785,7 @@ DescribePackagesFilterTypeDef = TypedDict(
     "DescribePackagesFilterTypeDef",
     {
         "Name": DescribePackagesFilterNameType,
-        "Value": List[str],
+        "Value": Sequence[str],
     },
     total=False,
 )
@@ -791,7 +793,7 @@ DescribePackagesFilterTypeDef = TypedDict(
 DescribePackagesRequestRequestTypeDef = TypedDict(
     "DescribePackagesRequestRequestTypeDef",
     {
-        "Filters": List["DescribePackagesFilterTypeDef"],
+        "Filters": Sequence["DescribePackagesFilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -906,6 +908,7 @@ DomainInfoTypeDef = TypedDict(
     "DomainInfoTypeDef",
     {
         "DomainName": str,
+        "EngineType": EngineTypeType,
     },
     total=False,
 )
@@ -1033,7 +1036,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
     total=False,
 )
@@ -1196,6 +1199,14 @@ LimitsTypeDef = TypedDict(
     total=False,
 )
 
+ListDomainNamesRequestRequestTypeDef = TypedDict(
+    "ListDomainNamesRequestRequestTypeDef",
+    {
+        "EngineType": EngineTypeType,
+    },
+    total=False,
+)
+
 ListDomainNamesResponseTypeDef = TypedDict(
     "ListDomainNamesResponseTypeDef",
     {
@@ -1516,7 +1527,7 @@ RemoveTagsRequestRequestTypeDef = TypedDict(
     "RemoveTagsRequestRequestTypeDef",
     {
         "ARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1699,9 +1710,9 @@ _OptionalUpdateDomainConfigRequestRequestTypeDef = TypedDict(
         "SnapshotOptions": "SnapshotOptionsTypeDef",
         "VPCOptions": "VPCOptionsTypeDef",
         "CognitoOptions": "CognitoOptionsTypeDef",
-        "AdvancedOptions": Dict[str, str],
+        "AdvancedOptions": Mapping[str, str],
         "AccessPolicies": str,
-        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
+        "LogPublishingOptions": Mapping[LogTypeType, "LogPublishingOptionTypeDef"],
         "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
@@ -1769,7 +1780,7 @@ _OptionalUpgradeDomainRequestRequestTypeDef = TypedDict(
     "_OptionalUpgradeDomainRequestRequestTypeDef",
     {
         "PerformCheckOnly": bool,
-        "AdvancedOptions": Dict[str, str],
+        "AdvancedOptions": Mapping[str, str],
     },
     total=False,
 )
@@ -1837,8 +1848,8 @@ VPCDerivedInfoTypeDef = TypedDict(
 VPCOptionsTypeDef = TypedDict(
     "VPCOptionsTypeDef",
     {
-        "SubnetIds": List[str],
-        "SecurityGroupIds": List[str],
+        "SubnetIds": Sequence[str],
+        "SecurityGroupIds": Sequence[str],
     },
     total=False,
 )
